@@ -382,7 +382,7 @@ public class ResourcesListViewPanel extends FramedPanel {
 					}
 
 				}));
-		listView.getSelectionModel().setSelectionMode(SelectionMode.SINGLE);
+		listView.getSelectionModel().setSelectionMode(SelectionMode.MULTI);
 		listView.getSelectionModel().addSelectionChangedHandler(
 				new SelectionChangedHandler<ResourceTDDescriptor>() {
 					@Override
@@ -569,8 +569,12 @@ public class ResourcesListViewPanel extends FramedPanel {
 
 			@Override
 			public void onSelection(SelectionEvent<Item> event) {
-				ResourceTDDescriptor selected = listView.getSelectionModel()
-						.getSelectedItem();
+				List<ResourceTDDescriptor> resources= listView.getSelectionModel()
+						.getSelectedItems();
+				ResourceTDDescriptor selected=null;
+				if(resources!=null&&resources.size()>0){
+					selected=resources.get(0);
+				}
 				Log.debug("selected: " + selected);
 				requestOpen(selected);
 			}
@@ -584,8 +588,12 @@ public class ResourcesListViewPanel extends FramedPanel {
 
 			@Override
 			public void onSelection(SelectionEvent<Item> event) {
-				ResourceTDDescriptor selected = listView.getSelectionModel()
-						.getSelectedItem();
+				List<ResourceTDDescriptor> resources= listView.getSelectionModel()
+						.getSelectedItems();
+				ResourceTDDescriptor selected=null;
+				if(resources!=null&&resources.size()>0){
+					selected=resources.get(0);
+				}
 				Log.debug("selected: " + selected);
 				requestSave(selected);
 			}
@@ -599,10 +607,11 @@ public class ResourcesListViewPanel extends FramedPanel {
 
 			@Override
 			public void onSelection(SelectionEvent<Item> event) {
-				ResourceTDDescriptor selected = listView.getSelectionModel()
-						.getSelectedItem();
+				List<ResourceTDDescriptor> selected= listView.getSelectionModel()
+						.getSelectedItems();
 				Log.debug("selected: " + selected);
-				requestRemove(selected);
+				ArrayList<ResourceTDDescriptor> resources=new ArrayList<ResourceTDDescriptor>(selected);
+				requestRemove(resources);
 			}
 
 		});
@@ -770,10 +779,11 @@ public class ResourcesListViewPanel extends FramedPanel {
 		});
 	}
 
-	protected void requestRemove(ResourceTDDescriptor resourceTDDescriptor) {
-
+	protected void requestRemove(ArrayList<ResourceTDDescriptor> resourcesList) {
+		ArrayList<ResourceTDDescriptor> resources=new ArrayList<ResourceTDDescriptor>(resourcesList);
+		
 		removeResourceSession = new RemoveResourceSession(trId,
-				resourceTDDescriptor);
+				resources);
 
 		TDGWTServiceAsync.INSTANCE.removeResource(removeResourceSession,
 				new AsyncCallback<Void>() {
@@ -928,12 +938,38 @@ public class ResourcesListViewPanel extends FramedPanel {
 
 			InternalURITD genericFileResourceTD = (InternalURITD) resource;
 			String name = resourceTDDescriptor.getName();
+			
+			/*
+			MimeTypeSupport ext=null;
+			String extentionInName=null;
+			if(name!=null){
+				List<String> nameS=null;
+				try{
+					nameS=Arrays.asList(name.split("\\.(?=[^\\.]+$)"));
+				} catch(Throwable e) {
+					Log.error("No valid name for resource: "+name);
+				}
+				
+				if(nameS!=null&&nameS.size()>1){
+					extentionInName=nameS.get(nameS.size()-1);
+					ext=MimeTypeSupport.getMimeTypeSupportFromExtension("."+extentionInName);
+					
+				}
+			}
+			if(ext==null){
+				
+		    */
+			
 			MimeTypeSupport mts = MimeTypeSupport
 					.getMimeTypeSupportFromMimeName(genericFileResourceTD
 							.getMimeType());
 			if (mts != null) {
 				name = name + mts.getExtension();
 			}
+			
+			/*
+			 }
+			 */
 
 			UriResolverSession uriResolverSession = new UriResolverSession(
 					genericFileResourceTD.getId(), ApplicationType.SMP_ID,
